@@ -53,12 +53,6 @@
  * #CheeseWidget.
  */
 
-G_DEFINE_TYPE (CheeseCamera, cheese_camera, G_TYPE_OBJECT)
-
-#define CHEESE_CAMERA_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHEESE_TYPE_CAMERA, CheeseCameraPrivate))
-
-#define CHEESE_CAMERA_ERROR cheese_camera_error_quark ()
-
 struct _CheeseCameraPrivate
 {
   GstBus *bus;
@@ -102,6 +96,12 @@ struct _CheeseCameraPrivate
   CheeseCameraDeviceMonitor *monitor;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (CheeseCamera, cheese_camera, G_TYPE_OBJECT)
+
+#define CHEESE_CAMERA_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHEESE_TYPE_CAMERA, CheeseCameraPrivate))
+
+#define CHEESE_CAMERA_ERROR cheese_camera_error_quark ()
+
 enum
 {
   PROP_0,
@@ -496,18 +496,22 @@ cheese_camera_set_video_recording (CheeseCamera *camera, GError **error)
   prof = gst_encoding_container_profile_new("WebM audio/video",
       "Standard WebM/VP8/Vorbis",
       caps, NULL);
+  gst_caps_unref (caps);
 
   caps = gst_caps_from_string("video/x-vp8");
   v_prof = gst_encoding_video_profile_new(caps, NULL, NULL, 0);
   gst_encoding_video_profile_set_variableframerate(v_prof, TRUE);
   gst_encoding_profile_set_preset((GstEncodingProfile*) v_prof, video_preset);
   gst_encoding_container_profile_add_profile(prof, (GstEncodingProfile*) v_prof);
+  gst_caps_unref (caps);
 
   caps = gst_caps_from_string("audio/x-vorbis");
   gst_encoding_container_profile_add_profile(prof,
       (GstEncodingProfile*) gst_encoding_audio_profile_new(caps, NULL, NULL, 0));
+  gst_caps_unref (caps);
 
   g_object_set (priv->camerabin, "video-profile", prof, NULL);
+  gst_encoding_profile_unref (prof);
 }
 
 /*
@@ -1080,6 +1084,7 @@ cheese_camera_set_tags (CheeseCamera *camera)
         GST_TAG_MERGE_REPLACE);
 
   gst_date_time_unref (datetime);
+  gst_tag_list_unref (taglist);
 }
 
 /**
@@ -1459,14 +1464,12 @@ cheese_camera_class_init (CheeseCameraClass *klass)
                                                            G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_properties (object_class, PROP_LAST, properties);
-
-  g_type_class_add_private (klass, sizeof (CheeseCameraPrivate));
 }
 
 static void
 cheese_camera_init (CheeseCamera *camera)
 {
-  CheeseCameraPrivate *priv = camera->priv = CHEESE_CAMERA_GET_PRIVATE (camera);
+  CheeseCameraPrivate *priv = camera->priv = cheese_camera_get_instance_private (camera);
 
   priv->is_recording            = FALSE;
   priv->pipeline_is_playing     = FALSE;
